@@ -2,6 +2,11 @@ source 'https://rubygems.org'
 
 gemspec
 
+group :maintenance, optional: true do
+	gem "bake-modernize"
+	gem "bake-bundler"
+end
+
 # gem "async", path: "../async"
 # gem "async-io", path: "../async-io"
 
